#!/bin/sh
# minutes and seconds, frames - illegal frames
./wavsplit --frames 12 ~/waves/long.wav 50:01:12.2 119:59:2.2

# minutes and seconds, frames - illegal frames
./wavsplit --frames 24 ~/waves/long.wav 50:01:24.0 119:59:2.2

# minutes and seconds, frames - illegal frames
./wavsplit --frames 25 ~/waves/long.wav 50:01:25.0 119:59:2.2

# minutes and seconds, frames - illegal frames
./wavsplit --frames 30 ~/waves/long.wav 50:01:30.0 119:59:2.2

# minutes and seconds, frames - illegal frames
./wavsplit --frames 75 ~/waves/long.wav 50:01:75.0 119:59:2.2

# minutes and seconds, frames OK
./wavsplit --frames 12 ~/waves/long.wav 50:01:11.99 119:59:2.2

# minutes and seconds, frames OK
./wavsplit --frames 24 ~/waves/long.wav 50:01:23.99 119:59:2.2

# minutes and seconds, frames OK
./wavsplit --frames 25 ~/waves/long.wav 50:01:24.99 119:59:2.2

# minutes and seconds, frames OK
./wavsplit --frames 30 ~/waves/long.wav 50:01:29.99 119:59:2.2

# minutes and seconds, frames OK
./wavsplit --frames 75 ~/waves/long.wav 50:01:74.99 119:59:2.2

# minutes and seconds - illegal seconds
./wavsplit ~/waves/long.wav 50:01.3 119:60.2

# minutes and seconds OK
./wavsplit ~/waves/long.wav  50:01.3 119:10.2 

# hours, minutes, seconds - illegal minutes
./wavsplit --Hours ~/waves/long.wav 0:60:01.3 1:59:10.2

# hours, minutes, seconds - illegal seconds
./wavsplit --Hours ~/waves/long.wav 0:50:01.3 1:59:60.2

# hours, minutes, seconds - OK
./wavsplit --Hours ~/waves/long.wav 0:50:01.3 1:59:10.2

# seconds
./wavsplit --seconds ~/waves/long.wav 3001.3 7150.2

# Track times: minutes and seconds, frames - OK
./wavsplit --frames --tracktimes ~/waves/long.wav 3:1:74 2:50:20

# Track times: hours, minutes, seconds - OK
./wavsplit --seconds --tracktimes ~/waves/long.wav 180.3 240.0

# hours, minutes, seconds - illegal order of splits (not ascending) 
./wavsplit --seconds  ~/waves/long.wav 240.0 180.3 500.01
